summaryrefslogtreecommitdiffstats
path: root/ash
diff options
context:
space:
mode:
authorestade <estade@chromium.org>2016-01-06 16:24:57 -0800
committerCommit bot <commit-bot@chromium.org>2016-01-07 00:25:45 +0000
commit0cf40d355f3b24fdcaf57e54050bb4fc9bb52c1d (patch)
treeb95896d9f5aec4b06953dbc543d27709fa7eca09 /ash
parent53ed4db73a14cdd24186d313a4504361a0003677 (diff)
downloadchromium_src-0cf40d355f3b24fdcaf57e54050bb4fc9bb52c1d.zip
chromium_src-0cf40d355f3b24fdcaf57e54050bb4fc9bb52c1d.tar.gz
chromium_src-0cf40d355f3b24fdcaf57e54050bb4fc9bb52c1d.tar.bz2
Vectorize CrOS window control icons.
BUG=569067 Review URL: https://codereview.chromium.org/1566563002 Cr-Commit-Position: refs/heads/master@{#367969}
Diffstat (limited to 'ash')
-rw-r--r--ash/ash.gyp1
-rw-r--r--ash/frame/caption_buttons/frame_caption_button.cc17
-rw-r--r--ash/frame/caption_buttons/frame_caption_button.h14
-rw-r--r--ash/frame/caption_buttons/frame_caption_button_container_view.cc12
-rw-r--r--ash/frame/caption_buttons/frame_caption_button_container_view.h11
-rw-r--r--ash/frame/caption_buttons/frame_caption_button_container_view_unittest.cc3
-rw-r--r--ash/frame/caption_buttons/frame_size_button_unittest.cc3
-rw-r--r--ash/frame/default_header_painter.cc35
-rw-r--r--ash/frame/default_header_painter.h2
-rw-r--r--ash/resources/ash_resources.grd14
-rw-r--r--ash/resources/default_100_percent/common/window_control_icon_back.pngbin130 -> 0 bytes
-rw-r--r--ash/resources/default_100_percent/common/window_control_icon_close.pngbin128 -> 0 bytes
-rw-r--r--ash/resources/default_100_percent/common/window_control_icon_close_white.pngbin127 -> 0 bytes
-rw-r--r--ash/resources/default_100_percent/common/window_control_icon_left_snapped.pngbin132 -> 0 bytes
-rw-r--r--ash/resources/default_100_percent/common/window_control_icon_left_snapped_white.pngbin130 -> 0 bytes
-rw-r--r--ash/resources/default_100_percent/common/window_control_icon_maximize.pngbin82 -> 0 bytes
-rw-r--r--ash/resources/default_100_percent/common/window_control_icon_maximize_white.pngbin83 -> 0 bytes
-rw-r--r--ash/resources/default_100_percent/common/window_control_icon_minimize.pngbin76 -> 0 bytes
-rw-r--r--ash/resources/default_100_percent/common/window_control_icon_minimize_white.pngbin75 -> 0 bytes
-rw-r--r--ash/resources/default_100_percent/common/window_control_icon_restore.pngbin91 -> 0 bytes
-rw-r--r--ash/resources/default_100_percent/common/window_control_icon_restore_white.pngbin91 -> 0 bytes
-rw-r--r--ash/resources/default_100_percent/common/window_control_icon_right_snapped.pngbin129 -> 0 bytes
-rw-r--r--ash/resources/default_100_percent/common/window_control_icon_right_snapped_white.pngbin127 -> 0 bytes
-rw-r--r--ash/resources/default_200_percent/common/window_control_icon_back.pngbin257 -> 0 bytes
-rw-r--r--ash/resources/default_200_percent/common/window_control_icon_close.pngbin169 -> 0 bytes
-rw-r--r--ash/resources/default_200_percent/common/window_control_icon_close_white.pngbin161 -> 0 bytes
-rw-r--r--ash/resources/default_200_percent/common/window_control_icon_left_snapped.pngbin265 -> 0 bytes
-rw-r--r--ash/resources/default_200_percent/common/window_control_icon_left_snapped_white.pngbin238 -> 0 bytes
-rw-r--r--ash/resources/default_200_percent/common/window_control_icon_maximize.pngbin89 -> 0 bytes
-rw-r--r--ash/resources/default_200_percent/common/window_control_icon_maximize_white.pngbin89 -> 0 bytes
-rw-r--r--ash/resources/default_200_percent/common/window_control_icon_minimize.pngbin81 -> 0 bytes
-rw-r--r--ash/resources/default_200_percent/common/window_control_icon_minimize_white.pngbin80 -> 0 bytes
-rw-r--r--ash/resources/default_200_percent/common/window_control_icon_restore.pngbin96 -> 0 bytes
-rw-r--r--ash/resources/default_200_percent/common/window_control_icon_restore_white.pngbin96 -> 0 bytes
-rw-r--r--ash/resources/default_200_percent/common/window_control_icon_right_snapped.pngbin247 -> 0 bytes
-rw-r--r--ash/resources/default_200_percent/common/window_control_icon_right_snapped_white.pngbin230 -> 0 bytes
36 files changed, 58 insertions, 54 deletions
diff --git a/ash/ash.gyp b/ash/ash.gyp
index 292f1cf..6b695b5 100644
--- a/ash/ash.gyp
+++ b/ash/ash.gyp
@@ -972,6 +972,7 @@
'../ui/events/platform/events_platform.gyp:events_platform',
'../ui/gfx/gfx.gyp:gfx',
'../ui/gfx/gfx.gyp:gfx_geometry',
+ '../ui/gfx/gfx.gyp:gfx_vector_icons',
'../ui/keyboard/keyboard.gyp:keyboard',
'../ui/message_center/message_center.gyp:message_center',
'../ui/resources/ui_resources.gyp:ui_resources',
diff --git a/ash/frame/caption_buttons/frame_caption_button.cc b/ash/frame/caption_buttons/frame_caption_button.cc
index 042201c..300e2ba 100644
--- a/ash/frame/caption_buttons/frame_caption_button.cc
+++ b/ash/frame/caption_buttons/frame_caption_button.cc
@@ -4,10 +4,12 @@
#include "ash/frame/caption_buttons/frame_caption_button.h"
-#include "ui/base/resource/resource_bundle.h"
#include "ui/gfx/animation/slide_animation.h"
#include "ui/gfx/animation/throb_animation.h"
#include "ui/gfx/canvas.h"
+#include "ui/gfx/color_palette.h"
+#include "ui/gfx/paint_vector_icon.h"
+#include "ui/gfx/vector_icons_public.h"
namespace ash {
@@ -40,8 +42,9 @@ FrameCaptionButton::FrameCaptionButton(views::ButtonListener* listener,
: CustomButton(listener),
icon_(icon),
paint_as_active_(false),
+ use_light_images_(false),
alpha_(255),
- icon_image_id_(-1),
+ icon_image_id_(gfx::VectorIconId::VECTOR_ICON_NONE),
swap_images_animation_(new gfx::SlideAnimation(this)) {
swap_images_animation_->Reset(1);
@@ -55,8 +58,8 @@ FrameCaptionButton::~FrameCaptionButton() {
void FrameCaptionButton::SetImage(CaptionButtonIcon icon,
Animate animate,
- int icon_image_id) {
- // The early return is dependant on |animate| because callers use SetImage()
+ gfx::VectorIconId icon_image_id) {
+ // The early return is dependent on |animate| because callers use SetImage()
// with ANIMATE_NO to progress the crossfade animation to the end.
if (icon == icon_ &&
(animate == ANIMATE_YES || !swap_images_animation_->is_animating()) &&
@@ -69,9 +72,9 @@ void FrameCaptionButton::SetImage(CaptionButtonIcon icon,
icon_ = icon;
icon_image_id_ = icon_image_id;
-
- ui::ResourceBundle& rb = ui::ResourceBundle::GetSharedInstance();
- icon_image_ = *rb.GetImageSkiaNamed(icon_image_id);
+ icon_image_ = gfx::CreateVectorIcon(
+ icon_image_id, 12,
+ use_light_images_ ? SK_ColorWHITE : gfx::kChromeIconGrey);
if (animate == ANIMATE_YES) {
swap_images_animation_->Reset(0);
diff --git a/ash/frame/caption_buttons/frame_caption_button.h b/ash/frame/caption_buttons/frame_caption_button.h
index bd12e12..a8ed2a7 100644
--- a/ash/frame/caption_buttons/frame_caption_button.h
+++ b/ash/frame/caption_buttons/frame_caption_button.h
@@ -14,6 +14,7 @@
namespace gfx {
class SlideAnimation;
+enum class VectorIconId;
}
namespace ash {
@@ -36,7 +37,9 @@ class ASH_EXPORT FrameCaptionButton : public views::CustomButton {
// the button crossfades to the new visuals. If the image id matches the one
// currently used by the button and |animate| is ANIMATE_NO, the crossfade
// animation is progressed to the end.
- void SetImage(CaptionButtonIcon icon, Animate animate, int icon_image_id);
+ void SetImage(CaptionButtonIcon icon,
+ Animate animate,
+ gfx::VectorIconId icon_image_id);
// Returns true if the button is crossfading to new visuals set in
// SetImage().
@@ -54,11 +57,13 @@ class ASH_EXPORT FrameCaptionButton : public views::CustomButton {
paint_as_active_ = paint_as_active;
}
+ void set_use_light_images(bool light) { use_light_images_ = light; }
+
CaptionButtonIcon icon() const {
return icon_;
}
- int icon_image_id() const { return icon_image_id_; }
+ gfx::VectorIconId icon_image_id() const { return icon_image_id_; }
void set_size(const gfx::Size& size) { size_ = size; }
@@ -81,11 +86,14 @@ class ASH_EXPORT FrameCaptionButton : public views::CustomButton {
// Whether the button should be painted as active.
bool paint_as_active_;
+ // Whether to paint in a lighter color (for use on dark backgrounds).
+ bool use_light_images_;
+
// Current alpha to use for painting.
int alpha_;
// The image id and image used to paint the button's icon.
- int icon_image_id_;
+ gfx::VectorIconId icon_image_id_;
gfx::ImageSkia icon_image_;
// The icon image to crossfade from.
diff --git a/ash/frame/caption_buttons/frame_caption_button_container_view.cc b/ash/frame/caption_buttons/frame_caption_button_container_view.cc
index 4a59a6b..d500513 100644
--- a/ash/frame/caption_buttons/frame_caption_button_container_view.cc
+++ b/ash/frame/caption_buttons/frame_caption_button_container_view.cc
@@ -22,6 +22,7 @@
#include "ui/gfx/canvas.h"
#include "ui/gfx/geometry/insets.h"
#include "ui/gfx/geometry/point.h"
+#include "ui/gfx/vector_icons_public.h"
#include "ui/strings/grit/ui_strings.h" // Accessibility names
#include "ui/views/widget/widget.h"
#include "ui/views/widget/widget_delegate.h"
@@ -149,8 +150,9 @@ void FrameCaptionButtonContainerView::TestApi::EndAnimations() {
container_view_->maximize_mode_animation_->End();
}
-void FrameCaptionButtonContainerView::SetButtonImage(CaptionButtonIcon icon,
- int icon_image_id) {
+void FrameCaptionButtonContainerView::SetButtonImage(
+ CaptionButtonIcon icon,
+ gfx::VectorIconId icon_image_id) {
button_icon_id_map_[icon] = icon_image_id;
FrameCaptionButton* buttons[] = {
@@ -168,6 +170,12 @@ void FrameCaptionButtonContainerView::SetPaintAsActive(bool paint_as_active) {
close_button_->set_paint_as_active(paint_as_active);
}
+void FrameCaptionButtonContainerView::SetUseLightImages(bool light) {
+ minimize_button_->set_use_light_images(light);
+ size_button_->set_use_light_images(light);
+ close_button_->set_use_light_images(light);
+}
+
void FrameCaptionButtonContainerView::ResetWindowControls() {
SetButtonsToNormal(ANIMATE_NO);
}
diff --git a/ash/frame/caption_buttons/frame_caption_button_container_view_unittest.cc b/ash/frame/caption_buttons/frame_caption_button_container_view_unittest.cc
index 4ca5436..ff87fd4 100644
--- a/ash/frame/caption_buttons/frame_caption_button_container_view_unittest.cc
+++ b/ash/frame/caption_buttons/frame_caption_button_container_view_unittest.cc
@@ -11,6 +11,7 @@
#include "ash/wm/maximize_mode/maximize_mode_controller.h"
#include "grit/ash_resources.h"
#include "ui/gfx/geometry/rect.h"
+#include "ui/gfx/vector_icons_public.h"
#include "ui/views/widget/widget.h"
#include "ui/views/widget/widget_delegate.h"
@@ -77,7 +78,7 @@ class FrameCaptionButtonContainerViewTest : public ash::test::AshTestBase {
GetAshLayoutSize(AshLayoutSize::NON_BROWSER_CAPTION_BUTTON));
for (int icon = 0; icon < CAPTION_BUTTON_ICON_COUNT; ++icon) {
container->SetButtonImage(static_cast<CaptionButtonIcon>(icon),
- IDR_AURA_WINDOW_CONTROL_ICON_CLOSE);
+ gfx::VectorIconId::WINDOW_CONTROL_CLOSE);
}
}
diff --git a/ash/frame/caption_buttons/frame_size_button_unittest.cc b/ash/frame/caption_buttons/frame_size_button_unittest.cc
index ab86ac4..c63e49e 100644
--- a/ash/frame/caption_buttons/frame_size_button_unittest.cc
+++ b/ash/frame/caption_buttons/frame_size_button_unittest.cc
@@ -18,6 +18,7 @@
#include "ui/events/test/event_generator.h"
#include "ui/gfx/display.h"
#include "ui/gfx/screen.h"
+#include "ui/gfx/vector_icons_public.h"
#include "ui/views/widget/widget.h"
#include "ui/views/widget/widget_delegate.h"
@@ -65,7 +66,7 @@ class TestWidgetDelegate : public views::WidgetDelegateView {
for (int icon = 0; icon < CAPTION_BUTTON_ICON_COUNT; ++icon) {
caption_button_container_->SetButtonImage(
static_cast<CaptionButtonIcon>(icon),
- IDR_AURA_WINDOW_CONTROL_ICON_CLOSE);
+ gfx::VectorIconId::WINDOW_CONTROL_CLOSE);
}
AddChildView(caption_button_container_);
diff --git a/ash/frame/default_header_painter.cc b/ash/frame/default_header_painter.cc
index 135671a..ed39751 100644
--- a/ash/frame/default_header_painter.cc
+++ b/ash/frame/default_header_painter.cc
@@ -21,6 +21,7 @@
#include "ui/gfx/image/image.h"
#include "ui/gfx/scoped_canvas.h"
#include "ui/gfx/skia_util.h"
+#include "ui/gfx/vector_icons_public.h"
#include "ui/views/view.h"
#include "ui/views/widget/native_widget_aura.h"
#include "ui/views/widget/widget.h"
@@ -158,7 +159,8 @@ void DefaultHeaderPainter::PaintHeader(gfx::Canvas* canvas, Mode mode) {
}
void DefaultHeaderPainter::LayoutHeader() {
- UpdateSizeButtonImages(ShouldUseLightImages());
+ caption_button_container_->SetUseLightImages(ShouldUseLightImages());
+ UpdateSizeButtonImages();
caption_button_container_->Layout();
gfx::Size caption_button_container_size =
@@ -295,39 +297,28 @@ bool DefaultHeaderPainter::ShouldUseLightImages() {
}
void DefaultHeaderPainter::UpdateAllButtonImages() {
- bool use_light_images = ShouldUseLightImages();
+ caption_button_container_->SetUseLightImages(ShouldUseLightImages());
caption_button_container_->SetButtonImage(
- CAPTION_BUTTON_ICON_MINIMIZE,
- use_light_images ? IDR_AURA_WINDOW_CONTROL_ICON_MINIMIZE_WHITE
- : IDR_AURA_WINDOW_CONTROL_ICON_MINIMIZE);
+ CAPTION_BUTTON_ICON_MINIMIZE, gfx::VectorIconId::WINDOW_CONTROL_MINIMIZE);
- UpdateSizeButtonImages(use_light_images);
+ UpdateSizeButtonImages();
caption_button_container_->SetButtonImage(
- CAPTION_BUTTON_ICON_CLOSE, use_light_images
- ? IDR_AURA_WINDOW_CONTROL_ICON_CLOSE_WHITE
- : IDR_AURA_WINDOW_CONTROL_ICON_CLOSE);
+ CAPTION_BUTTON_ICON_CLOSE, gfx::VectorIconId::WINDOW_CONTROL_CLOSE);
caption_button_container_->SetButtonImage(
CAPTION_BUTTON_ICON_LEFT_SNAPPED,
- use_light_images ? IDR_AURA_WINDOW_CONTROL_ICON_LEFT_SNAPPED_WHITE
- : IDR_AURA_WINDOW_CONTROL_ICON_LEFT_SNAPPED);
+ gfx::VectorIconId::WINDOW_CONTROL_LEFT_SNAPPED);
caption_button_container_->SetButtonImage(
CAPTION_BUTTON_ICON_RIGHT_SNAPPED,
- use_light_images ? IDR_AURA_WINDOW_CONTROL_ICON_RIGHT_SNAPPED_WHITE
- : IDR_AURA_WINDOW_CONTROL_ICON_RIGHT_SNAPPED);
+ gfx::VectorIconId::WINDOW_CONTROL_RIGHT_SNAPPED);
}
-void DefaultHeaderPainter::UpdateSizeButtonImages(bool use_light_images) {
- int icon_id = 0;
- if (frame_->IsMaximized() || frame_->IsFullscreen()) {
- icon_id = use_light_images ? IDR_AURA_WINDOW_CONTROL_ICON_RESTORE_WHITE
- : IDR_AURA_WINDOW_CONTROL_ICON_RESTORE;
- } else {
- icon_id = use_light_images ? IDR_AURA_WINDOW_CONTROL_ICON_MAXIMIZE_WHITE
- : IDR_AURA_WINDOW_CONTROL_ICON_MAXIMIZE;
- }
+void DefaultHeaderPainter::UpdateSizeButtonImages() {
+ gfx::VectorIconId icon_id = frame_->IsMaximized() || frame_->IsFullscreen()
+ ? gfx::VectorIconId::WINDOW_CONTROL_RESTORE
+ : gfx::VectorIconId::WINDOW_CONTROL_MAXIMIZE;
caption_button_container_->SetButtonImage(
CAPTION_BUTTON_ICON_MAXIMIZE_RESTORE, icon_id);
}
diff --git a/ash/frame/default_header_painter.h b/ash/frame/default_header_painter.h
index d867f6f1..d56c265 100644
--- a/ash/frame/default_header_painter.h
+++ b/ash/frame/default_header_painter.h
@@ -84,7 +84,7 @@ class ASH_EXPORT DefaultHeaderPainter : public HeaderPainter,
void UpdateAllButtonImages();
// Updates the size button's images.
- void UpdateSizeButtonImages(bool use_light_images);
+ void UpdateSizeButtonImages();
// Returns the header bounds in the coordinates of |view_|. The header is
// assumed to be positioned at the top left corner of |view_| and to have the
diff --git a/ash/resources/ash_resources.grd b/ash/resources/ash_resources.grd
index 2ab7410..cb56d86 100644
--- a/ash/resources/ash_resources.grd
+++ b/ash/resources/ash_resources.grd
@@ -180,20 +180,6 @@
<structure type="chrome_scaled_image" name="IDR_AURA_UBER_TRAY_VOLUME_LEVELS" file="cros/status/status_volume_dark.png" />
<structure type="chrome_scaled_image" name="IDR_AURA_UBER_TRAY_VOLUME_MUTE" file="cros/status/status_volume_mute.png" />
- <structure type="chrome_scaled_image" name="IDR_AURA_WINDOW_CONTROL_ICON_BACK" file="common/window_control_icon_back.png" />
- <structure type="chrome_scaled_image" name="IDR_AURA_WINDOW_CONTROL_ICON_CLOSE" file="common/window_control_icon_close.png" />
- <structure type="chrome_scaled_image" name="IDR_AURA_WINDOW_CONTROL_ICON_CLOSE_WHITE" file="common/window_control_icon_close_white.png" />
- <structure type="chrome_scaled_image" name="IDR_AURA_WINDOW_CONTROL_ICON_LEFT_SNAPPED" file="common/window_control_icon_left_snapped.png" />
- <structure type="chrome_scaled_image" name="IDR_AURA_WINDOW_CONTROL_ICON_LEFT_SNAPPED_WHITE" file="common/window_control_icon_left_snapped_white.png" />
- <structure type="chrome_scaled_image" name="IDR_AURA_WINDOW_CONTROL_ICON_MAXIMIZE" file="common/window_control_icon_maximize.png" />
- <structure type="chrome_scaled_image" name="IDR_AURA_WINDOW_CONTROL_ICON_MAXIMIZE_WHITE" file="common/window_control_icon_maximize_white.png" />
- <structure type="chrome_scaled_image" name="IDR_AURA_WINDOW_CONTROL_ICON_MINIMIZE" file="common/window_control_icon_minimize.png" />
- <structure type="chrome_scaled_image" name="IDR_AURA_WINDOW_CONTROL_ICON_MINIMIZE_WHITE" file="common/window_control_icon_minimize_white.png" />
- <structure type="chrome_scaled_image" name="IDR_AURA_WINDOW_CONTROL_ICON_RESTORE" file="common/window_control_icon_restore.png" />
- <structure type="chrome_scaled_image" name="IDR_AURA_WINDOW_CONTROL_ICON_RESTORE_WHITE" file="common/window_control_icon_restore_white.png" />
- <structure type="chrome_scaled_image" name="IDR_AURA_WINDOW_CONTROL_ICON_RIGHT_SNAPPED" file="common/window_control_icon_right_snapped.png" />
- <structure type="chrome_scaled_image" name="IDR_AURA_WINDOW_CONTROL_ICON_RIGHT_SNAPPED_WHITE" file="common/window_control_icon_right_snapped_white.png" />
-
<structure type="chrome_scaled_image" name="IDR_AURA_WINDOW_HEADER_SHADE_INACTIVE_BOTTOM" file="common/window_header_shade_bottom_inactive.png" />
<structure type="chrome_scaled_image" name="IDR_AURA_WINDOW_HEADER_SHADE_INACTIVE_LEFT" file="common/window_header_shade_left_inactive.png" />
<structure type="chrome_scaled_image" name="IDR_AURA_WINDOW_HEADER_SHADE_INACTIVE_RIGHT" file="common/window_header_shade_right_inactive.png" />
diff --git a/ash/resources/default_100_percent/common/window_control_icon_back.png b/ash/resources/default_100_percent/common/window_control_icon_back.png
deleted file mode 100644
index 2e0723d..0000000
--- a/ash/resources/default_100_percent/common/window_control_icon_back.png
+++ /dev/null
Binary files differ
diff --git a/ash/resources/default_100_percent/common/window_control_icon_close.png b/ash/resources/default_100_percent/common/window_control_icon_close.png
deleted file mode 100644
index db26524..0000000
--- a/ash/resources/default_100_percent/common/window_control_icon_close.png
+++ /dev/null
Binary files differ
diff --git a/ash/resources/default_100_percent/common/window_control_icon_close_white.png b/ash/resources/default_100_percent/common/window_control_icon_close_white.png
deleted file mode 100644
index 1bc6a84..0000000
--- a/ash/resources/default_100_percent/common/window_control_icon_close_white.png
+++ /dev/null
Binary files differ
diff --git a/ash/resources/default_100_percent/common/window_control_icon_left_snapped.png b/ash/resources/default_100_percent/common/window_control_icon_left_snapped.png
deleted file mode 100644
index 4374068..0000000
--- a/ash/resources/default_100_percent/common/window_control_icon_left_snapped.png
+++ /dev/null
Binary files differ
diff --git a/ash/resources/default_100_percent/common/window_control_icon_left_snapped_white.png b/ash/resources/default_100_percent/common/window_control_icon_left_snapped_white.png
deleted file mode 100644
index 58be13a..0000000
--- a/ash/resources/default_100_percent/common/window_control_icon_left_snapped_white.png
+++ /dev/null
Binary files differ
diff --git a/ash/resources/default_100_percent/common/window_control_icon_maximize.png b/ash/resources/default_100_percent/common/window_control_icon_maximize.png
deleted file mode 100644
index ce0cf13..0000000
--- a/ash/resources/default_100_percent/common/window_control_icon_maximize.png
+++ /dev/null
Binary files differ
diff --git a/ash/resources/default_100_percent/common/window_control_icon_maximize_white.png b/ash/resources/default_100_percent/common/window_control_icon_maximize_white.png
deleted file mode 100644
index 5dc6ccb..0000000
--- a/ash/resources/default_100_percent/common/window_control_icon_maximize_white.png
+++ /dev/null
Binary files differ
diff --git a/ash/resources/default_100_percent/common/window_control_icon_minimize.png b/ash/resources/default_100_percent/common/window_control_icon_minimize.png
deleted file mode 100644
index 48c262c..0000000
--- a/ash/resources/default_100_percent/common/window_control_icon_minimize.png
+++ /dev/null
Binary files differ
diff --git a/ash/resources/default_100_percent/common/window_control_icon_minimize_white.png b/ash/resources/default_100_percent/common/window_control_icon_minimize_white.png
deleted file mode 100644
index b085916..0000000
--- a/ash/resources/default_100_percent/common/window_control_icon_minimize_white.png
+++ /dev/null
Binary files differ
diff --git a/ash/resources/default_100_percent/common/window_control_icon_restore.png b/ash/resources/default_100_percent/common/window_control_icon_restore.png
deleted file mode 100644
index 565dae9..0000000
--- a/ash/resources/default_100_percent/common/window_control_icon_restore.png
+++ /dev/null
Binary files differ
diff --git a/ash/resources/default_100_percent/common/window_control_icon_restore_white.png b/ash/resources/default_100_percent/common/window_control_icon_restore_white.png
deleted file mode 100644
index 5b51c15..0000000
--- a/ash/resources/default_100_percent/common/window_control_icon_restore_white.png
+++ /dev/null
Binary files differ
diff --git a/ash/resources/default_100_percent/common/window_control_icon_right_snapped.png b/ash/resources/default_100_percent/common/window_control_icon_right_snapped.png
deleted file mode 100644
index 53551d4..0000000
--- a/ash/resources/default_100_percent/common/window_control_icon_right_snapped.png
+++ /dev/null
Binary files differ
diff --git a/ash/resources/default_100_percent/common/window_control_icon_right_snapped_white.png b/ash/resources/default_100_percent/common/window_control_icon_right_snapped_white.png
deleted file mode 100644
index b02d33c..0000000
--- a/ash/resources/default_100_percent/common/window_control_icon_right_snapped_white.png
+++ /dev/null
Binary files differ
diff --git a/ash/resources/default_200_percent/common/window_control_icon_back.png b/ash/resources/default_200_percent/common/window_control_icon_back.png
deleted file mode 100644
index 34e907b..0000000
--- a/ash/resources/default_200_percent/common/window_control_icon_back.png
+++ /dev/null
Binary files differ
diff --git a/ash/resources/default_200_percent/common/window_control_icon_close.png b/ash/resources/default_200_percent/common/window_control_icon_close.png
deleted file mode 100644
index 5c14ecd..0000000
--- a/ash/resources/default_200_percent/common/window_control_icon_close.png
+++ /dev/null
Binary files differ
diff --git a/ash/resources/default_200_percent/common/window_control_icon_close_white.png b/ash/resources/default_200_percent/common/window_control_icon_close_white.png
deleted file mode 100644
index 27cef0f..0000000
--- a/ash/resources/default_200_percent/common/window_control_icon_close_white.png
+++ /dev/null
Binary files differ
diff --git a/ash/resources/default_200_percent/common/window_control_icon_left_snapped.png b/ash/resources/default_200_percent/common/window_control_icon_left_snapped.png
deleted file mode 100644
index f8db919..0000000
--- a/ash/resources/default_200_percent/common/window_control_icon_left_snapped.png
+++ /dev/null
Binary files differ
diff --git a/ash/resources/default_200_percent/common/window_control_icon_left_snapped_white.png b/ash/resources/default_200_percent/common/window_control_icon_left_snapped_white.png
deleted file mode 100644
index 6e938b8..0000000
--- a/ash/resources/default_200_percent/common/window_control_icon_left_snapped_white.png
+++ /dev/null
Binary files differ
diff --git a/ash/resources/default_200_percent/common/window_control_icon_maximize.png b/ash/resources/default_200_percent/common/window_control_icon_maximize.png
deleted file mode 100644
index a5947a5..0000000
--- a/ash/resources/default_200_percent/common/window_control_icon_maximize.png
+++ /dev/null
Binary files differ
diff --git a/ash/resources/default_200_percent/common/window_control_icon_maximize_white.png b/ash/resources/default_200_percent/common/window_control_icon_maximize_white.png
deleted file mode 100644
index 5e17aae..0000000
--- a/ash/resources/default_200_percent/common/window_control_icon_maximize_white.png
+++ /dev/null
Binary files differ
diff --git a/ash/resources/default_200_percent/common/window_control_icon_minimize.png b/ash/resources/default_200_percent/common/window_control_icon_minimize.png
deleted file mode 100644
index 837b433..0000000
--- a/ash/resources/default_200_percent/common/window_control_icon_minimize.png
+++ /dev/null
Binary files differ
diff --git a/ash/resources/default_200_percent/common/window_control_icon_minimize_white.png b/ash/resources/default_200_percent/common/window_control_icon_minimize_white.png
deleted file mode 100644
index cb295d0..0000000
--- a/ash/resources/default_200_percent/common/window_control_icon_minimize_white.png
+++ /dev/null
Binary files differ
diff --git a/ash/resources/default_200_percent/common/window_control_icon_restore.png b/ash/resources/default_200_percent/common/window_control_icon_restore.png
deleted file mode 100644
index 5a327bb..0000000
--- a/ash/resources/default_200_percent/common/window_control_icon_restore.png
+++ /dev/null
Binary files differ
diff --git a/ash/resources/default_200_percent/common/window_control_icon_restore_white.png b/ash/resources/default_200_percent/common/window_control_icon_restore_white.png
deleted file mode 100644
index a2e02ed..0000000
--- a/ash/resources/default_200_percent/common/window_control_icon_restore_white.png
+++ /dev/null
Binary files differ
diff --git a/ash/resources/default_200_percent/common/window_control_icon_right_snapped.png b/ash/resources/default_200_percent/common/window_control_icon_right_snapped.png
deleted file mode 100644
index 8eed437..0000000
--- a/ash/resources/default_200_percent/common/window_control_icon_right_snapped.png
+++ /dev/null
Binary files differ
diff --git a/ash/resources/default_200_percent/common/window_control_icon_right_snapped_white.png b/ash/resources/default_200_percent/common/window_control_icon_right_snapped_white.png
deleted file mode 100644
index d8d5cfd..0000000
--- a/ash/resources/default_200_percent/common/window_control_icon_right_snapped_white.png
+++ /dev/null
Binary files differ
diff --git a/ash/frame/caption_buttons/frame_caption_button_container_view.h b/ash/frame/caption_buttons/frame_caption_button_container_view.h
index 01cf0ec..8b93aab 100644
--- a/ash/frame/caption_buttons/frame_caption_button_container_view.h
+++ b/ash/frame/caption_buttons/frame_caption_button_container_view.h
@@ -16,6 +16,7 @@
namespace gfx {
class SlideAnimation;
+enum class VectorIconId;
}
namespace views {
@@ -65,15 +66,19 @@ class ASH_EXPORT FrameCaptionButtonContainerView
DISALLOW_COPY_AND_ASSIGN(TestApi);
};
// Sets the resource id of the image to paint the button for |icon|. The
// FrameCaptionButtonContainerView will keep track of the image to use for
// |icon| even if none of the buttons currently use |icon|.
- void SetButtonImage(CaptionButtonIcon icon, int icon_image_id);
+ void SetButtonImage(CaptionButtonIcon icon, gfx::VectorIconId icon_image_id);
// Sets whether the buttons should be painted as active. Does not schedule
// a repaint.
void SetPaintAsActive(bool paint_as_active);
+ // Sets whether the buttons should be painted in a lighter color (for use on
+ // dark backgrounds).
+ void SetUseLightImages(bool light);
+
// Tell the window controls to reset themselves to the normal state.
void ResetWindowControls();
@@ -139,7 +144,7 @@ class ASH_EXPORT FrameCaptionButtonContainerView
// Mapping of the image ID needed to paint a button for each of the values of
// CaptionButtonIcon.
- std::map<CaptionButtonIcon, int> button_icon_id_map_;
+ std::map<CaptionButtonIcon, gfx::VectorIconId> button_icon_id_map_;
// Animation that affects the position of |minimize_button_| and the
// visibility of |size_button_|.
@@ -65,15 +66,19 @@ class ASH_EXPORT FrameCaptionButtonContainerView
DISALLOW_COPY_AND_ASSIGN(TestApi);
};
- // Sets the resource id of the image to paint the button for |icon|. The
+ // Sets the id of the vector image to paint the button for |icon|. The
// FrameCaptionButtonContainerView will keep track of the image to use for
// |icon| even if none of the buttons currently use |icon|.